@@ -147,7 +147,7 @@ default it will use L<Storable> and L<MIME::Base64> to serialize and
 deserialize the data, but this can be configured easily. 
 
 This is a subclass of L<Plack::Session::Store> and implements
-it's full interface.
+its full interface.
 
 =head1 SESSION TABLE SCHEMA
 
